"""
Main interface for databrew service literal definitions.

Usage::

    ```python
    from mypy_boto3_databrew.literals import CompressionFormat

    data: CompressionFormat = "BROTLI"
    ```
"""
import sys

if sys.version_info >= (3, 8):
    from typing import Literal
else:
    from typing_extensions import Literal


__all__ = (
    "CompressionFormat",
    "EncryptionMode",
    "InputFormat",
    "JobRunState",
    "JobType",
    "ListDatasetsPaginatorName",
    "ListJobRunsPaginatorName",
    "ListJobsPaginatorName",
    "ListProjectsPaginatorName",
    "ListRecipeVersionsPaginatorName",
    "ListRecipesPaginatorName",
    "ListSchedulesPaginatorName",
    "LogSubscription",
    "Order",
    "OrderedBy",
    "OutputFormat",
    "ParameterType",
    "SampleMode",
    "SampleType",
    "SessionStatus",
    "Source",
)


CompressionFormat = Literal[
    "BROTLI", "BZIP2", "DEFLATE", "GZIP", "LZ4", "LZO", "SNAPPY", "ZLIB", "ZSTD"
]
EncryptionMode = Literal["SSE-KMS", "SSE-S3"]
InputFormat = Literal["CSV", "EXCEL", "JSON", "PARQUET"]
JobRunState = Literal[
    "FAILED", "RUNNING", "STARTING", "STOPPED", "STOPPING", "SUCCEEDED", "TIMEOUT"
]
JobType = Literal["PROFILE", "RECIPE"]
ListDatasetsPaginatorName = Literal["list_datasets"]
ListJobRunsPaginatorName = Literal["list_job_runs"]
ListJobsPaginatorName = Literal["list_jobs"]
ListProjectsPaginatorName = Literal["list_projects"]
ListRecipeVersionsPaginatorName = Literal["list_recipe_versions"]
ListRecipesPaginatorName = Literal["list_recipes"]
ListSchedulesPaginatorName = Literal["list_schedules"]
LogSubscription = Literal["DISABLE", "ENABLE"]
Order = Literal["ASCENDING", "DESCENDING"]
OrderedBy = Literal["LAST_MODIFIED_DATE"]
OutputFormat = Literal["AVRO", "CSV", "GLUEPARQUET", "JSON", "ORC", "PARQUET", "XML"]
ParameterType = Literal["Datetime", "Number", "String"]
SampleMode = Literal["CUSTOM_ROWS", "FULL_DATASET"]
SampleType = Literal["FIRST_N", "LAST_N", "RANDOM"]
SessionStatus = Literal[
    "ASSIGNED",
    "FAILED",
    "INITIALIZING",
    "PROVISIONING",
    "READY",
    "RECYCLING",
    "ROTATING",
    "TERMINATED",
    "TERMINATING",
    "UPDATING",
]
Source = Literal["DATA-CATALOG", "DATABASE", "S3"]



"""
Main interface for databrew service client paginators.

Usage::

    ```python
    import boto3

    from mypy_boto3_databrew import GlueDataBrewClient
    from mypy_boto3_databrew.paginator import (
        ListDatasetsPaginator,
        ListJobRunsPaginator,
        ListJobsPaginator,
        ListProjectsPaginator,
        ListRecipeVersionsPaginator,
        ListRecipesPaginator,
        ListSchedulesPaginator,
    )

    client: GlueDataBrewClient = boto3.client("databrew")

    list_datasets_paginator: ListDatasetsPaginator = client.get_paginator("list_datasets")
    list_job_runs_paginator: ListJobRunsPaginator = client.get_paginator("list_job_runs")
    list_jobs_paginator: ListJobsPaginator = client.get_paginator("list_jobs")
    list_projects_paginator: ListProjectsPaginator = client.get_paginator("list_projects")
    list_recipe_versions_paginator: ListRecipeVersionsPaginator = client.get_paginator("list_recipe_versions")
    list_recipes_paginator: ListRecipesPaginator = client.get_paginator("list_recipes")
    list_schedules_paginator: ListSchedulesPaginator = client.get_paginator("list_schedules")
    ```
"""
from typing import Iterator

from botocore.paginate import Paginator as Boto3Paginator

from mypy_boto3_databrew.type_defs import (
    ListDatasetsResponseTypeDef,
    ListJobRunsResponseTypeDef,
    ListJobsResponseTypeDef,
    ListProjectsResponseTypeDef,
    ListRecipesResponseTypeDef,
    ListRecipeVersionsResponseTypeDef,
    ListSchedulesResponseTypeDef,
    PaginatorConfigTypeDef,
)

__all__ = (
    "ListDatasetsPaginator",
    "ListJobRunsPaginator",
    "ListJobsPaginator",
    "ListProjectsPaginator",
    "ListRecipeVersionsPaginator",
    "ListRecipesPaginator",
    "ListSchedulesPaginator",
)


class ListDatasetsPaginator(Boto3Paginator):
    """
    [Paginator.ListDatasets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/databrew.html#GlueDataBrew.Paginator.ListDatasets)
    """

    def paginate(
        self, PaginationConfig: PaginatorConfigTypeDef = None
    ) -> Iterator[ListDatasetsResponseTypeDef]:
        """
        [ListDatasets.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/databrew.html#GlueDataBrew.Paginator.ListDatasets.paginate)
        """


class ListJobRunsPaginator(Boto3Paginator):
    """
    [Paginator.ListJobRuns documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/databrew.html#GlueDataBrew.Paginator.ListJobRuns)
    """

    def paginate(
        self, Name: str, PaginationConfig: PaginatorConfigTypeDef = None
    ) -> Iterator[ListJobRunsResponseTypeDef]:
        """
        [ListJobRuns.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/databrew.html#GlueDataBrew.Paginator.ListJobRuns.paginate)
        """


class ListJobsPaginator(Boto3Paginator):
    """
    [Paginator.ListJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/databrew.html#GlueDataBrew.Paginator.ListJobs)
    """

    def paginate(
        self,
        DatasetName: str = None,
        ProjectName: str = None,
        PaginationConfig: PaginatorConfigTypeDef = None,
    ) -> Iterator[ListJobsResponseTypeDef]:
        """
        [ListJobs.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/databrew.html#GlueDataBrew.Paginator.ListJobs.paginate)
        """


class ListProjectsPaginator(Boto3Paginator):
    """
    [Paginator.ListProjects documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/databrew.html#GlueDataBrew.Paginator.ListProjects)
    """

    def paginate(
        self, PaginationConfig: PaginatorConfigTypeDef = None
    ) -> Iterator[ListProjectsResponseTypeDef]:
        """
        [ListProjects.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/databrew.html#GlueDataBrew.Paginator.ListProjects.paginate)
        """


class ListRecipeVersionsPaginator(Boto3Paginator):
    """
    [Paginator.ListRecipeVersions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/databrew.html#GlueDataBrew.Paginator.ListRecipeVersions)
    """

    def paginate(
        self, Name: str, PaginationConfig: PaginatorConfigTypeDef = None
    ) -> Iterator[ListRecipeVersionsResponseTypeDef]:
        """
        [ListRecipeVersions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/databrew.html#GlueDataBrew.Paginator.ListRecipeVersions.paginate)
        """


class ListRecipesPaginator(Boto3Paginator):
    """
    [Paginator.ListRecipes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/databrew.html#GlueDataBrew.Paginator.ListRecipes)
    """

    def paginate(
        self, RecipeVersion: str = None, PaginationConfig: PaginatorConfigTypeDef = None
    ) -> Iterator[ListRecipesResponseTypeDef]:
        """
        [ListRecipes.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/databrew.html#GlueDataBrew.Paginator.ListRecipes.paginate)
        """


class ListSchedulesPaginator(Boto3Paginator):
    """
    [Paginator.ListSchedules documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/databrew.html#GlueDataBrew.Paginator.ListSchedules)
    """

    def paginate(
        self, JobName: str = None, PaginationConfig: PaginatorConfigTypeDef = None
    ) -> Iterator[ListSchedulesResponseTypeDef]:
        """
        [ListSchedules.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/databrew.html#GlueDataBrew.Paginator.ListSchedules.paginate)
        """
